@@ -1,4 +1,4 @@
-#  This file is part of Python Builder
+#  This file is part of PyBuilder
 #
 #  Copyright 2011-2013 PyBuilder Team
 #
@@ -26,7 +26,7 @@ from pybuilder.errors import PythonbuilderException
 from pybuilder.execution import ExecutionManager
 from pybuilder.reactor import Reactor
 from pybuilder.terminal import BOLD, BROWN, RED, GREEN, bold, styled_text, fg, italic, \
-    write, write_line, write_error, write_error_line, draw_line
+    print_text, print_text_line, print_error, print_error_line, draw_line
 from pybuilder.utils import format_timestamp
 
 PROPERTY_OVERRIDE_PATTERN = re.compile(r'^[a-zA-Z0-9_]+=.*')
@@ -49,7 +49,9 @@ class StdOutLogger(Logger):
         return "[ERROR]"
 
     def _do_log(self, level, message, *arguments):
-        sys.stdout.write("%s %s\n" % (self._level_to_string(level), self._format_message(message, *arguments)))
+        formatted_message = self._format_message(message, *arguments)
+        log_level = self._level_to_string(level)
+        print_text_line("{0} {1}".format(log_level, formatted_message))
 
 
 class ColoredStdOutLogger(StdOutLogger):
@@ -173,45 +175,92 @@ def init_logger(options):
     return logger
 
 
-def print_summary(successful, summary, start, end, options, failure_message):
+def print_build_summary(options, summary):
+    print_text_line("Build Summary")
+    print_text_line("%20s: %s" % ("Project", summary.project.name))
+    print_text_line("%20s: %s" % ("Version", summary.project.version))
+    print_text_line("%20s: %s" % ("Base directory", summary.project.basedir))
+    print_text_line("%20s: %s" % ("Environments", ", ".join(options.environments)))
+
+    task_summary = ""
+    for task in summary.task_summaries:
+        task_summary += " %s [%d ms]" % (task.task, task.execution_time)
+
+    print_text_line("%20s:%s" % ("Tasks", task_summary))
+
+
+def print_styled_text(text, options, *style_attributes):
+    if should_colorize(options):
+        text = styled_text(text, *style_attributes)
+    print_text(text)
+
+
+def print_styled_text_line(text, options, *style_attributes):
+    print_styled_text(text + "\n", options, *style_attributes)
+
+
+def print_build_status(failure_message, options, successful):
     draw_line()
     if successful:
-        msg = "BUILD SUCCESSFUL\n"
-        if should_colorize(options):
-            msg = styled_text(msg, BOLD, fg(GREEN))
+        print_styled_text_line("BUILD SUCCESSFUL", options, BOLD, fg(GREEN))
     else:
-        msg = "BUILD FAILED - %s\n" % failure_message
-        if should_colorize(options):
-            msg = styled_text(msg, BOLD, fg(RED))
-    write(msg)
+        print_styled_text_line("BUILD FAILED - {0}".format(failure_message), options, BOLD, fg(RED))
     draw_line()
 
-    if successful and summary:
-        write_line("Build Summary")
-        write_line("%20s: %s" % ("Project", summary.project.name))
-        write_line("%20s: %s" % ("Version", summary.project.version))
-        write_line("%20s: %s" % ("Base directory", summary.project.basedir))
-        write_line("%20s: %s" % ("Environments", ", ".join(options.environments)))
-
-        task_summary = ""
-        for task in summary.task_summaries:
-            task_summary += " %s [%d ms]" % (task.task, task.execution_time)
-
-        write_line("%20s:%s" % ("Tasks", task_summary))
 
+def print_elapsed_time_summary(start, end):
     time_needed = end - start
     millis = ((time_needed.days * 24 * 60 * 60) + time_needed.seconds) * 1000 + time_needed.microseconds / 1000
+    print_text_line("Build finished at %s" % format_timestamp(end))
+    print_text_line("Build took %d seconds (%d ms)" % (time_needed.seconds, millis))
 
-    write_line("Build finished at %s" % format_timestamp(end))
-    write_line("Build took %d seconds (%d ms)" % (time_needed.seconds, millis))
+
+def print_summary(successful, summary, start, end, options, failure_message):
+    print_build_status(failure_message, options, successful)
+
+    if successful and summary:
+        print_build_summary(options, summary)
+
+    print_elapsed_time_summary(start, end)
+
+
+def length_of_longest_string(list_of_strings):
+    if len(list_of_strings) == 0:
+        return 0
+
+    result = 0
+    for string in list_of_strings:
+        length_of_string = len(string)
+        if length_of_string > result:
+            result = length_of_string
+
+    return result
+
+
+def print_list_of_tasks(reactor):
+    print_text_line('Tasks found for project "%s":' % reactor.project.name)
+
+    tasks = reactor.get_tasks()
+    column_length = length_of_longest_string(list(map(lambda task: task.name, tasks)))
+    column_length += 4
+
+    for task in sorted(tasks):
+        task_name = task.name.rjust(column_length)
+        task_description = " ".join(task.description) or "<no description available>"
+        print_text_line("{0} - {1}".format(task_name, task_description))
+
+        if task.dependencies:
+            whitespace = (column_length + 3) * " "
+            depends_on_message = "depends on tasks: %s" % " ".join(task.dependencies)
+            print_text_line(whitespace + depends_on_message)
 
 
 def main(*args):
     try:
         options, arguments = parse_options(args)
     except CommandLineUsageException as e:
-        write_error_line("Usage error: %s\n" % e)
-        write_error(e.usage)
+        print_error_line("Usage error: %s\n" % e)
+        print_error(e.usage)
         return 1
 
     start = datetime.datetime.now()
@@ -223,22 +272,12 @@ def main(*args):
         reactor.prepare_build(property_overrides=options.property_overrides,
                               project_directory=options.project_directory)
 
-        write_line("Tasks found in %s building in %s:" % (reactor.project.name, reactor.project.basedir))
-        write_line()
-        for task in sorted(reactor.get_tasks()):
-            write_line("%20s\t%s" % (task.name, " ".join(task.description) or "<no description available>"))
-            if task.dependencies:
-                write_line("\t\t\tdepends on tasks: %s" % " ".join(task.dependencies))
-            write_line()
+        print_list_of_tasks(reactor)
         return 0
 
-    banner = "PYBUILDER Version {0}".format(__version__)
-    if should_colorize(options):
-        banner = bold(banner)
-
     if not options.very_quiet:
-        write_line(banner)
-        write_line("Build started at %s" % format_timestamp(start))
+        print_styled_text_line("PYBUILDER Version {0}".format(__version__), options, BOLD)
+        print_text_line("Build started at %s" % format_timestamp(start))
         draw_line()
 
     successful = True
@@ -250,18 +289,11 @@ def main(*args):
             reactor.prepare_build(property_overrides=options.property_overrides,
                                   project_directory=options.project_directory)
 
-            if options.verbose:
+            if options.verbose or options.debug:
                 logger.debug("Verbose output enabled.\n")
-                reactor.project.verbose = True
+                reactor.project.set_property("verbose", True)
 
-            if options.list_tasks:
-                for task in sorted(reactor.get_tasks()):
-                    write_line("%20s\t%s" % (task.name, task.description or "<no description available>"))
-                    if task.dependencies:
-                        write_line("\t\t\tdepends on tasks: %s" % " ".join(task.dependencies))
-                    write_line()
-            else:
-                summary = reactor.build(environments=options.environments, tasks=arguments)
+            summary = reactor.build(environments=options.environments, tasks=arguments)
 
         except KeyboardInterrupt:
             raise PythonbuilderException("Build aborted")
