@@ -1,4 +1,4 @@
-#   This file is part of Python Builder
+#   This file is part of PyBuilder
 #
 #   Copyright 2011-2013 PyBuilder Team
 #
@@ -14,12 +14,13 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-from pybuilder.core import task, depends, use_plugin
+from pybuilder.core import task, depends, description, use_plugin
 
 use_plugin("core")
 
 
 @task
+@description("Execute analysis plugins.")
 @depends("run_unit_tests")
 def analyze():
     pass
